@@ -1,9 +1,10 @@
-from viset.caltech import Caltech101
+from viset.library.caltech101 import Caltech101
 from viset.dataset import Viset
 from viset.show import imshow
 from time import sleep
 import os.path
 
+
 def test_create():
     print '[test_viset.test_create]: creating new viset for caltech101'    
     return Caltech101().export()
@@ -34,19 +35,17 @@ def test_open(dbfile):
             print 'Correctly raised exceptions'        
     except:
         raise
-                
-        
-def test_query(dbfile):
-    print '[test_viset.test_query]: query database'
-    db = Viset(dbfile)
-    print db.query(table='/images', row=0, field='url')
-    print db.dbobj.root.images[0]['url']  # natural naming
 
     
 def test_summary(dbfile):
     print '[test_viset.test_summary]: displaying summary of database'    
     print Viset(dbfile)
 
+
+def test_iterator(dbfile):
+    # why does this fail?  need to explicitly set db=Viset(...) then db.image in iterator
+    for im in Viset(dbfile, verbose=True).image:
+        print type(im)
     
 def test_split(dbfile):
     print '[test_viset.test_split]: dataset splits'  
@@ -78,24 +77,18 @@ def test_labeling(dbfile):
     
 def test_verbosity(dbfile):
     print '[test_viset.test_verbosity]: verbosity is true'
-    db = Viset(dbfile, async=False, verbose=True)
-    (im,anno) = db[0].next()
+    db = Viset(dbfile, verbose=True)
     print '[test_viset.test_verbosity]: verbosity is false'
-    db = Viset(dbfile, async=False, verbose=False)
-    (im,anno) = db[0].next()
-    
-    
+    db = Viset(dbfile, verbose=False)
 
 def main():
     dbfile = test_create()
     test_open(dbfile)
     test_summary(dbfile)
-    test_query(dbfile)
-    test_split(dbfile)
+    #    test_split(dbfile)
     test_verbosity(dbfile)    
-        
-
-  
+    #test_iterator(dbfile)
+    
 if __name__ == '__main__':
   main()
 
