@@ -41,7 +41,6 @@ class Cache():
     def __str__(self):
         return str('this is a string')
 
-
     def _url_fragment_options(self, url, sha1=None):
         default_opts = {'sha1':sha1, 'item':None, 'reader':None, 'id':None}
         url_scheme = urlparse.urlparse(url)[0]
@@ -60,7 +59,7 @@ class Cache():
         if reader == 'universal':
             return pylab.imread(filename)
         elif reader == 'mnist':
-            return viset.mnist.imread(filename, int(id))
+            return viset.library.mnist.imread(filename, int(id))
         else:
             self.quietprint('[viset.cache][ERROR]: reader type "' + str(reader) + '" unsupported', self._verbose)
             raise NotImplementedError()
@@ -99,7 +98,6 @@ class Cache():
             raise IOError()
         return obj
         
-        
     def download(self, url):        
         """Download element according to URL scheme"""
         self.free()  # garbage collection time?        
@@ -125,26 +123,36 @@ class Cache():
         
     def fetch(self, url, sha1=None):
         """Fetch and element and store in cache"""
-        if not isurl(url):
-            return None
         urlopts = self._url_fragment_options(url, sha1)
-        if not self.iscached(url):
-            quietprint('[viset.cache][MISS]: downloading \'' + str(url[0:63] + '...') + '\'', self._verbose)                                        
-            filename = self.download(url)
-            if isarchive(filename):
-                quietprint('[viset.cache][MISS]: extracting archive \'' + filename + '\'', self._verbose)
-                if urlopts['item'] is not None:
-                    filename = self.unpack(filename, sha1=urlopts['sha1'], item=urlopts['item'])
-                else:
-                    filename = self.unpack(filename, sha1=urlopts['sha1'], item=None)                        
-        else:
+        if isurl(url):            
+            if not self.iscached(url):
+                quietprint('[viset.cache][MISS]: downloading \'' + str(url[0:63] + '...') + '\'', self._verbose)                                        
+                filename = self.download(url)
+                if isarchive(filename):
+                    quietprint('[viset.cache][MISS]: extracting archive \'' + filename + '\'', self._verbose)
+                    if urlopts['item'] is not None:
+                        filename = self.unpack(filename, sha1=urlopts['sha1'], item=urlopts['item'])
+                    else:
+                        filename = self.unpack(filename, sha1=urlopts['sha1'], item=None)                        
+            else:
+                filename = self.cachefile(url)            
+                quietprint('[viset.cache][HIT]: retrieving \'' + filename + '\'', self._verbose)                                                     
+        elif viset.util.isfile(self.cachefile(url)):            
             filename = self.cachefile(url)            
             quietprint('[viset.cache][HIT]: retrieving \'' + filename + '\'', self._verbose)                                     
+        elif viset.util.isfile(self.abspath(path.basename(url))):
+            filename = self.abspath(path.basename(url))
+            quietprint('[viset.cache][HIT]: retrieving \'' + filename + '\'', self._verbose)                                     
+        else:
+            # nothing in cache or backing store
+            quietprint('[viset.cache][MISS]: \'' + url + '\' not available in cache', self._verbose)                                     
+            return None
+        
         quietprint('[viset.cache][HIT]: loading \'' + filename + '\'', self._verbose)                                         
         return self.load(filename, reader=urlopts['reader'], id=urlopts['id'])
     
     def get(self, url, sha1=None):
-        """Get an element from cache"""        
+        """Get an element from cache""" 
         try:
             return self.fetch(url, sha1=sha1)
         except KeyboardInterrupt:
@@ -190,7 +198,6 @@ class Cache():
         else:
             return urlhash 
 
-        
     def free(self):
         """Garbage collection"""
         if self._free_ctr == 0:
@@ -236,7 +243,42 @@ def quietprint(mystr, is_verbose):
     if is_verbose:
         print mystr
             
-            
+
+class CachedResult(object):
+    """Mirrors Python's AsyncResult class"""
+    _obj = None    
+    _url = None
+    _verbose = False
+    _cache = None
+
+    def __init__(self, url, verbose=True, cache=None):
+        self._verbose = verbose
+        if cache is None:
+            self._cache = Cache(verbose=self._verbose)
+        else:
+            self._cache = cache
+        self._url = url
+    
+    def successful():
+        return (self._obj is not None)
+    def wait(timeout):
+        socket.setdefaulttimeout(timeout)  # do not set globally        
+    def ready():
+        return (self._obj is not None)
+    
+    def get(self):
+        self._obj = self._cache.get(self._url)
+        return self._obj
+        
+    def __repr__(self):
+        return str('<viset.cache: obj=' + str(type(self._obj)) + ', cached=' + str(self._cache.iscached(self._url)) + ', URL=\'' + str(self._url) + '\'>')        
+    
+
+class CachedImage(CachedResult):
+    def __repr__(self):
+        return str('<viset.image: obj=' + str(type(self._obj)) + ', cached=' + str(self._cache.iscached(self._url)) + ', URL=\'' + str(self._url) + '\'>')        
+
+    
 ##     convert from viset:// to file:// or http://
 ##     viset:path_to_resource
 ##     viset://domain.com/
