@@ -17,6 +17,7 @@ def tolist(x):
         return x
     else:
         return [x]
+
     
 def isimg(path):
     (filename, ext) = os.path.splitext(path)
@@ -31,8 +32,8 @@ def isfile(path):
 def isviset(obj):
     return (str(type(obj)) in ['<class \'viset.types.Image\'>', '<class \'viset.types.Data\'>'])
 
-def isarchive(path):
-    (filename, ext) = os.path.splitext(path)
+def isarchive(filename):
+    (filebase, ext) = splitextension(filename)
     if ext.lower() in ['.egg','.jar','.tar','.tar.bz2','.tar.gz','.tgz','.tz2','.zip']:
         return True
     else:
@@ -93,11 +94,13 @@ def touch(filename, mystr=''):
     f.write(str(mystr))
     f.close()
 
-def setfetched(cachedir):
-    touch(path.join(cachedir, '.fetched'), mystr=str(str(datetime.datetime.now())+'\n'))
-
-def wasfetched(cachedir):
-    return isfile(path.join(str(cachedir), '.fetched'))
-
-
 
+def splitextension(filename):
+    (head, tail) = path.split(filename)
+    try:
+        (base, ext) = string.split(tail,'.',1)  # for .tar.gz    
+        ext = '.'+ext
+    except:
+        base = tail
+        ext = None
+    return (os.path.join(head, base), ext) # for consistency with splitext
